summaryrefslogtreecommitdiff
path: root/src/buildstream/_loader/loadelement.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/buildstream/_loader/loadelement.py')
-rw-r--r--src/buildstream/_loader/loadelement.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/buildstream/_loader/loadelement.py b/src/buildstream/_loader/loadelement.py
index 684c32554..24b4e7293 100644
--- a/src/buildstream/_loader/loadelement.py
+++ b/src/buildstream/_loader/loadelement.py
@@ -62,10 +62,11 @@ class LoadElement():
#
# Public members
#
- self.node = node # The YAML node
- self.name = filename # The element name
- self.full_name = None # The element full name (with associated junction)
- self.deps = None # The list of Dependency objects
+ self.node = node # The YAML node
+ self.name = filename # The element name
+ self.full_name = None # The element full name (with associated junction)
+ self.deps = None # The list of Dependency objects
+ self.meta_done = False # If the MetaElement for this LoadElement is done
self.node_id = next(self._counter)
#